Date: 07 14, 2001 11:10:07 AM

# Debug Toolbar

The Debug Toolbar provides controls to display parse trees, intermediate files and output files.

Button | Name | Description
| Toggle Page Mode | Maintains coordinated sets of documents. For example, when the user runs the analyzer, its corresponding output and tree windows are updated automatically. Similarly when selecting passes in the Ana Tab, Page Mode activates the Next Text and Previous Text buttons.
| Previous Text | Displays previous input text file according to the ordering in the Text Tab. Works in Page Mode to automatically update the open documents associated with the input text.
| Next Text | Displays the next input text file according to the ordering in the Text Tab. Works in Page Mode to automatically update the open documents associated with the input text.
| View Current Text | Displays the currently selected input data file in the Workspace.
| View Web Page | Displays Web page for the HTML file selected in the Text Tab.
| View Pass File | Displays the currently selected pass file in the analyzer sequence in the Workspace.
| View Parse Tree | Displays the full parse tree of a parsed document in the Workspace. This includes character position and white spaces in the document.
| View Concept Tree | Displays the concept tree of a parsed document in the Workspace.
| Toggle Node Variables | When selected, enables the display of node variables in the parse tree.
| View Dump Files | Displays the output files associated with a parsed document in the Workspace. When there are multiple files, the pulldown tab to the right of the button lists available files.
| View Output File | Displays the output.txt file associated with parsed input document in the Workspace.